bitvec_postprocess_norm

Function bitvec_postprocess_norm 

pub fn bitvec_postprocess_norm()
This function is useful only for verification in F*. Used with postprocess_rewrite, this tactic:

  1. Applies a series of rewrite rules (the lemmas marked with REWRITE_RULE)
  2. Normalizes, bottom-up, every sub-expressions typed BitVec<_> inside the body of a function. This tactic should be used on expressions that compute a static permutation of bits.